namespace HabitSharp.Notifications {
    /// <summary>
    /// A notification that shows a modal window on the web client to tell the user that item drops are now available.
    /// Item drops are unlocked starting from level 3.
    /// </summary>
    [NotificationType("DROPS_ENABLED")]
    public class DropsEnabledNotification : Notification { }

    /// <summary>
    /// A notification that shows a modal window on the web client to tell the user that the Rebirth Orb is now available.
    /// Rebirths are unlocked at level 50 (but become free at level 100).
    /// </summary>
    [NotificationType("REBIRTH_ENABLED")]
    public class RebirthEnabledNotification : Notification { }

    /// <summary>
    /// A notification that shows a modal window on the web client to tell the user they achieved a Ultimate Gear achievement.
    /// Ultimate Gear means the user bought every single piece of basic equipment (that can be bought with gold) for their character's class.
    /// </summary>
    [NotificationType("ULTIMATE_GEAR_ACHIEVEMENT")]
    public class UltimateGearAchievementNotification : Notification { }

    /// <summary>
    /// A notification that shows a modal window on the web client to tell the user they achieved a Rebirth achievement.
    /// Rebirth achivements are obtained anytime the user uses a Rebirth Orb to start their character over from scratch.
    /// </summary>
    [NotificationType("REBIRTH_ACHIEVEMENT")]
    public class RebirthAchievementNotification : Notification { }

    /// <summary>
    /// A notification that shows a modal window on the web client to tell the user they achieved a Challenge Joined achievement.
    /// The Challenge Joined achievement is unlocked whenever the users joins any challenge.
    /// </summary>
    [NotificationType("CHALLENGE_JOINED_ACHIEVEMENT")]
    public class ChallengeJoinedAchievementNotification : Notification { }

    /// <summary>
    /// A notification that shows a modal window on the web client to tell the user they achieved a Streak achievement.
    /// Streak achievements are unlocked when completing a Daily 21 times.
    /// </summary>
    [NotificationType("STREAK_ACHIEVEMENT")]
    public class StreakAchievementNotification : Notification { }

    /// <summary>
    /// A notification that shows a modal window on the web client to tell the user they achieved a new Habitica contributor level.
    /// The user is then called a "hero". It unlocks a colored name tag, a place in the Habitica Heroes page and an achievement.
    /// </summary>
    [NotificationType("NEW_CONTRIBUTOR_LEVEL")]
    public class NewContributorLevelNotification : Notification { }

    /// <summary>
    /// A notification that shows a modal window on the web client to tell the user they won a challenge.
    /// </summary>
    [NotificationType("WON_CHALLENGE")]
    public class WonChallengeNotification : Notification { }

    /// <summary>
    /// A notification that shows a modal window on the web client to tell the user they unlocked a Guild Joined achievement.
    /// This achievement is unlocked whenever the user joins any guild.
    /// </summary>
    [NotificationType("GUILD_JOINED_ACHIEVEMENT")]
    public class GuildJoinedAchievementNotification : Notification { }

    /// <summary>
    /// A notification that shows a modal window on the web client to tell the user they unlocked an Invited Friend achievement.
    /// This achievement is unlocked whenever the user invites someone else by email and they register on Habitica.
    /// </summary>
    [NotificationType("INVITED_FRIEND_ACHIEVEMENT")]
    public class InvitedFriendAchievementNotification : Notification { }
}
